# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/metrics/v1/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(strmprivacy/api/metrics/v1/metrics.proto\x12\x1astrmprivacy.api.metrics.v1\x1a\x1fgoogle/api/field_behavior.proto\"\x17\n\x15GetSystemStateRequest\"k\n\x16GetSystemStateResponse\x12Q\n\roverall_state\x18\x01 \x01(\x0e\x32\'.strmprivacy.api.metrics.v1.SystemStateB\x03\xe0\x41\x03R\x0coverallState*S\n\x0bSystemState\x12\x1c\n\x18SYSTEM_STATE_UNSPECIFIED\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x0e\n\nMAJOR_DOWN\x10\x02\x12\x0e\n\nMINOR_DOWN\x10\x03\x32\x89\x01\n\x0eMetricsService\x12w\n\x0eGetSystemState\x12\x31.strmprivacy.api.metrics.v1.GetSystemStateRequest\x1a\x32.strmprivacy.api.metrics.v1.GetSystemStateResponseBf\n\x1dio.strmprivacy.api.metrics.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/metrics/v1;metricsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.metrics.v1.metrics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.metrics.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/metrics/v1;metrics'
  _GETSYSTEMSTATERESPONSE.fields_by_name['overall_state']._options = None
  _GETSYSTEMSTATERESPONSE.fields_by_name['overall_state']._serialized_options = b'\340A\003'
  _SYSTEMSTATE._serialized_start=239
  _SYSTEMSTATE._serialized_end=322
  _GETSYSTEMSTATEREQUEST._serialized_start=105
  _GETSYSTEMSTATEREQUEST._serialized_end=128
  _GETSYSTEMSTATERESPONSE._serialized_start=130
  _GETSYSTEMSTATERESPONSE._serialized_end=237
  _METRICSSERVICE._serialized_start=325
  _METRICSSERVICE._serialized_end=462
# @@protoc_insertion_point(module_scope)
