# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/consent_levels/v1/consent_levels_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/consent_levels/v1/consent_levels_v1.proto\x12!strmprivacy.api.consent_levels.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"h\n\x1fListConsentLevelMappingsRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x8a\x01\n ListConsentLevelMappingsResponse\x12\x66\n\x16\x63onsent_level_mappings\x18\x01 \x03(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMappingR\x14\x63onsentLevelMappings\"n\n DeleteConsentLevelMappingRequest\x12J\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02R\x03ref\"#\n!DeleteConsentLevelMappingResponse\"\x88\x01\n CreateConsentLevelMappingRequest\x12\x64\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMappingR\x13\x63onsentLevelMapping\"\x89\x01\n!CreateConsentLevelMappingResponse\x12\x64\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMappingR\x13\x63onsentLevelMapping\"k\n\x1dGetConsentLevelMappingRequest\x12J\n\x03ref\x18\x01 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1.ConsentLevelMappingRefB\x03\xe0\x41\x02R\x03ref\"\x86\x01\n\x1eGetConsentLevelMappingResponse\x12\x64\n\x15\x63onsent_level_mapping\x18\x01 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1.ConsentLevelMappingR\x13\x63onsentLevelMapping2\xb5\x05\n\x1b\x43onsentLevelMappingsService\x12\xa3\x01\n\x18ListConsentLevelMappings\x12\x42.strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsRequest\x1a\x43.strmprivacy.api.consent_levels.v1.ListConsentLevelMappingsResponse\x12\x9d\x01\n\x16GetConsentLevelMapping\x12@.strmprivacy.api.consent_levels.v1.GetConsentLevelMappingRequest\x1a\x41.strmprivacy.api.consent_levels.v1.GetConsentLevelMappingResponse\x12\xa6\x01\n\x19\x44\x65leteConsentLevelMapping\x12\x43.strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingRequest\x1a\x44.strmprivacy.api.consent_levels.v1.DeleteConsentLevelMappingResponse\x12\xa6\x01\n\x19\x43reateConsentLevelMapping\x12\x43.strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingRequest\x1a\x44.strmprivacy.api.consent_levels.v1.CreateConsentLevelMappingResponseB{\n$io.strmprivacy.api.consent_levels.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/consent_levels/v1;consent_levelsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.consent_levels.v1.consent_levels_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.consent_levels.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/consent_levels/v1;consent_levels'
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['billing_id']._options = None
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['project_id']._options = None
  _LISTCONSENTLEVELMAPPINGSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETECONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._options = None
  _DELETECONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETCONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._options = None
  _GETCONSENTLEVELMAPPINGREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTCONSENTLEVELMAPPINGSREQUEST._serialized_start=176
  _LISTCONSENTLEVELMAPPINGSREQUEST._serialized_end=280
  _LISTCONSENTLEVELMAPPINGSRESPONSE._serialized_start=283
  _LISTCONSENTLEVELMAPPINGSRESPONSE._serialized_end=421
  _DELETECONSENTLEVELMAPPINGREQUEST._serialized_start=423
  _DELETECONSENTLEVELMAPPINGREQUEST._serialized_end=533
  _DELETECONSENTLEVELMAPPINGRESPONSE._serialized_start=535
  _DELETECONSENTLEVELMAPPINGRESPONSE._serialized_end=570
  _CREATECONSENTLEVELMAPPINGREQUEST._serialized_start=573
  _CREATECONSENTLEVELMAPPINGREQUEST._serialized_end=709
  _CREATECONSENTLEVELMAPPINGRESPONSE._serialized_start=712
  _CREATECONSENTLEVELMAPPINGRESPONSE._serialized_end=849
  _GETCONSENTLEVELMAPPINGREQUEST._serialized_start=851
  _GETCONSENTLEVELMAPPINGREQUEST._serialized_end=958
  _GETCONSENTLEVELMAPPINGRESPONSE._serialized_start=961
  _GETCONSENTLEVELMAPPINGRESPONSE._serialized_end=1095
  _CONSENTLEVELMAPPINGSSERVICE._serialized_start=1098
  _CONSENTLEVELMAPPINGSSERVICE._serialized_end=1791
# @@protoc_insertion_point(module_scope)
