# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_subjects/v1/data_subjects_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/data_subjects/v1/data_subjects_v1.proto\x12 strmprivacy.api.data_subjects.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/descriptor.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"q\n\x1eListDataSubjectKeylinksRequest\x12&\n\x0f\x64\x61ta_subject_id\x18\x01 \x03(\tR\rdataSubjectId\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationId\"\x8c\x01\n\x1fListDataSubjectKeylinksResponse\x12i\n\x15\x64\x61ta_subject_keylinks\x18\x01 \x03(\x0b\x32\x35.strmprivacy.api.data_subjects.v1.DatasubjectKeylinksR\x13\x64\x61taSubjectKeylinks\"\xaf\x01\n\x1e\x41\x64\x64\x44\x61taSubjectsKeyLinksRequest\x12\"\n\nproject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12i\n\x15\x64\x61ta_subject_keylinks\x18\x02 \x03(\x0b\x32\x35.strmprivacy.api.data_subjects.v1.DatasubjectKeylinksR\x13\x64\x61taSubjectKeylinks\"\xd3\x02\n\x1f\x41\x64\x64\x44\x61taSubjectsKeyLinksResponse\x12!\n\x0cstored_count\x18\x01 \x01(\x03R\x0bstoredCount\x12s\n\x06issues\x18\x02 \x03(\x0b\x32W.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksResponse.AddDataSubjectsIssuesB\x02\x18\x01R\x06issues\x1a\x97\x01\n\x15\x41\x64\x64\x44\x61taSubjectsIssues\x12&\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tR\rdataSubjectId\x12\x19\n\x08key_link\x18\x02 \x01(\tR\x07keyLink\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\x1d\n\nissue_type\x18\x04 \x01(\tR\tissueType:\x02\x18\x01\"\xb5\x02\n\x13\x44\x61tasubjectKeylinks\x12+\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\rdataSubjectId\x12\x81\x01\n\x17keylinks_and_timestamps\x18\x02 \x03(\x0b\x32I.strmprivacy.api.data_subjects.v1.DatasubjectKeylinks.KeylinkAndTimestampR\x15keylinksAndTimestamps\x1am\n\x13KeylinkAndTimestamp\x12\x19\n\x08key_link\x18\x01 \x01(\tR\x07keyLink\x12;\n\x0b\x65xpiry_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nexpiryTime\"i\n\x19\x44\x65leteDataSubjectsRequest\x12#\n\rdata_subjects\x18\x01 \x03(\tR\x0c\x64\x61taSubjects\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationId\"R\n\x1a\x44\x65leteDataSubjectsResponse\x12\x34\n\x16\x64\x65leted_keylinks_count\x18\x01 \x01(\x03R\x14\x64\x65letedKeylinksCount\"~\n\x17ListDataSubjectsRequest\x12\x1d\n\npage_token\x18\x01 \x01(\tR\tpageToken\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\'\n\x0forganization_id\x18\x03 \x01(\tR\x0eorganizationId\"\xee\x01\n\x18ListDataSubjectsResponse\x12o\n\rdata_subjects\x18\x01 \x03(\x0b\x32J.strmprivacy.api.data_subjects.v1.ListDataSubjectsResponse.DataSubjectInfoR\x0c\x64\x61taSubjects\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x1a\x39\n\x0f\x44\x61taSubjectInfo\x12&\n\x0f\x64\x61ta_subject_id\x18\x01 \x01(\tR\rdataSubjectId2\xf5\x04\n\x13\x44\x61taSubjectsService\x12\x9e\x01\n\x17ListDataSubjectKeylinks\x12@.strmprivacy.api.data_subjects.v1.ListDataSubjectKeylinksRequest\x1a\x41.strmprivacy.api.data_subjects.v1.ListDataSubjectKeylinksResponse\x12\x9e\x01\n\x17\x41\x64\x64\x44\x61taSubjectsKeyLinks\x12@.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksRequest\x1a\x41.strmprivacy.api.data_subjects.v1.AddDataSubjectsKeyLinksResponse\x12\x8f\x01\n\x12\x44\x65leteDataSubjects\x12;.strmprivacy.api.data_subjects.v1.DeleteDataSubjectsRequest\x1a<.strmprivacy.api.data_subjects.v1.DeleteDataSubjectsResponse\x12\x89\x01\n\x10ListDataSubjects\x12\x39.strmprivacy.api.data_subjects.v1.ListDataSubjectsRequest\x1a:.strmprivacy.api.data_subjects.v1.ListDataSubjectsResponseBx\n#io.strmprivacy.api.data_subjects.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/data_subjects/v1;data_subjectsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_subjects.v1.data_subjects_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.data_subjects.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/data_subjects/v1;data_subjects'
  _ADDDATASUBJECTSKEYLINKSREQUEST.fields_by_name['project_id']._options = None
  _ADDDATASUBJECTSKEYLINKSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._options = None
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_options = b'\030\001'
  _ADDDATASUBJECTSKEYLINKSRESPONSE.fields_by_name['issues']._options = None
  _ADDDATASUBJECTSKEYLINKSRESPONSE.fields_by_name['issues']._serialized_options = b'\030\001'
  _DATASUBJECTKEYLINKS.fields_by_name['data_subject_id']._options = None
  _DATASUBJECTKEYLINKS.fields_by_name['data_subject_id']._serialized_options = b'\340A\002'
  _LISTDATASUBJECTKEYLINKSREQUEST._serialized_start=193
  _LISTDATASUBJECTKEYLINKSREQUEST._serialized_end=306
  _LISTDATASUBJECTKEYLINKSRESPONSE._serialized_start=309
  _LISTDATASUBJECTKEYLINKSRESPONSE._serialized_end=449
  _ADDDATASUBJECTSKEYLINKSREQUEST._serialized_start=452
  _ADDDATASUBJECTSKEYLINKSREQUEST._serialized_end=627
  _ADDDATASUBJECTSKEYLINKSRESPONSE._serialized_start=630
  _ADDDATASUBJECTSKEYLINKSRESPONSE._serialized_end=969
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_start=818
  _ADDDATASUBJECTSKEYLINKSRESPONSE_ADDDATASUBJECTSISSUES._serialized_end=969
  _DATASUBJECTKEYLINKS._serialized_start=972
  _DATASUBJECTKEYLINKS._serialized_end=1281
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP._serialized_start=1172
  _DATASUBJECTKEYLINKS_KEYLINKANDTIMESTAMP._serialized_end=1281
  _DELETEDATASUBJECTSREQUEST._serialized_start=1283
  _DELETEDATASUBJECTSREQUEST._serialized_end=1388
  _DELETEDATASUBJECTSRESPONSE._serialized_start=1390
  _DELETEDATASUBJECTSRESPONSE._serialized_end=1472
  _LISTDATASUBJECTSREQUEST._serialized_start=1474
  _LISTDATASUBJECTSREQUEST._serialized_end=1600
  _LISTDATASUBJECTSRESPONSE._serialized_start=1603
  _LISTDATASUBJECTSRESPONSE._serialized_end=1841
  _LISTDATASUBJECTSRESPONSE_DATASUBJECTINFO._serialized_start=1784
  _LISTDATASUBJECTSRESPONSE_DATASUBJECTINFO._serialized_end=1841
  _DATASUBJECTSSERVICE._serialized_start=1844
  _DATASUBJECTSSERVICE._serialized_end=2473
# @@protoc_insertion_point(module_scope)
