# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2strmprivacy/api/installations/v1/entities_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x02\n\x0cInstallation\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12\x64\n\x11installation_type\x18\x02 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\x12,\n\x12\x62illing_account_id\x18\x03 \x01(\tR\x10\x62illingAccountId\x12t\n\x18installation_credentials\x18\x04 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstallationCredentialsR\x17installationCredentials\"\x96\x01\n\x17InstallationCredentials\x12 \n\tclient_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x08\x63lientId\x12(\n\rclient_secret\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0c\x63lientSecret\x12/\n\x11image_pull_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0fimagePullSecret\"\xd6\x01\n\x12InstalledComponent\x12\x64\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02R\rcomponentType\x12Z\n\tinstances\x18\x02 \x03(\x0b\x32<.strmprivacy.api.installations.v1.InstalledComponentInstanceR\tinstances\"\x84\x01\n\x1aInstalledComponentInstance\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12Q\n\x06states\x18\x02 \x03(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateR\x06states\"\xef\x01\n\x1fInstalledComponentsCurrentState\x12\x64\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02R\rcomponentType\x12\x66\n\tinstances\x18\x02 \x03(\x0b\x32H.strmprivacy.api.installations.v1.InstalledComponentInstanceCurrentStateR\tinstances\"\x8e\x01\n&InstalledComponentInstanceCurrentState\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12O\n\x05state\x18\x02 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateR\x05state\"\xdb\x01\n\x17InstalledComponentState\x12>\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstateTime\x12\x61\n\nstate_type\x18\x02 \x01(\x0e\x32=.strmprivacy.api.installations.v1.InstalledComponentStateTypeB\x03\xe0\x41\x02R\tstateType\x12\x1d\n\x07message\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x07message*\x7f\n\x10InstallationType\x12!\n\x1dINSTALLATION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAAS\x10\x01\x12\x0f\n\x0bSELF_HOSTED\x10\x02\x12\x13\n\x0f\x41WS_MARKETPLACE\x10\x03\x12\x18\n\x14\x41WS_MARKETPLACE_PAYG\x10\x04*\xfb\x01\n\x16InstalledComponentType\x12(\n$INSTALLED_COMPONENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42\x41TCH_JOBS_AGENT\x10\x01\x12\x19\n\x15\x42\x41TCH_EXPORTERS_AGENT\x10\x02\x12\x19\n\x15KAFKA_EXPORTERS_AGENT\x10\x03\x12\x11\n\rSTREAMS_AGENT\x10\x04\x12\x11\n\rEVENT_GATEWAY\x10\x05\x12\x0e\n\nWEB_SOCKET\x10\x06\x12\x19\n\x15\x44\x41TA_CONNECTORS_AGENT\x10\x07\x12\x1a\n\x16\x43ONFLUENT_SCHEMA_PROXY\x10\x08*\x89\x01\n\x1bInstalledComponentStateType\x12.\n*INSTALLED_COMPONENT_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bPROVISIONED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x11\n\rSHUTTING_DOWN\x10\x04\x42x\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.entities_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _INSTALLATION.fields_by_name['id']._options = None
  _INSTALLATION.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLATION.fields_by_name['installation_type']._options = None
  _INSTALLATION.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._serialized_options = b'\340A\002'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._serialized_options = b'\340A\001'
  _INSTALLATIONTYPE._serialized_start=1572
  _INSTALLATIONTYPE._serialized_end=1699
  _INSTALLEDCOMPONENTTYPE._serialized_start=1702
  _INSTALLEDCOMPONENTTYPE._serialized_end=1953
  _INSTALLEDCOMPONENTSTATETYPE._serialized_start=1956
  _INSTALLEDCOMPONENTSTATETYPE._serialized_end=2093
  _INSTALLATION._serialized_start=155
  _INSTALLATION._serialized_end=456
  _INSTALLATIONCREDENTIALS._serialized_start=459
  _INSTALLATIONCREDENTIALS._serialized_end=609
  _INSTALLEDCOMPONENT._serialized_start=612
  _INSTALLEDCOMPONENT._serialized_end=826
  _INSTALLEDCOMPONENTINSTANCE._serialized_start=829
  _INSTALLEDCOMPONENTINSTANCE._serialized_end=961
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_start=964
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_end=1203
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_start=1206
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_end=1348
  _INSTALLEDCOMPONENTSTATE._serialized_start=1351
  _INSTALLEDCOMPONENTSTATE._serialized_end=1570
# @@protoc_insertion_point(module_scope)
