# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installed_components_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>strmprivacy/api/installations/v1/installed_components_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\"\xdc\x02\n$UpdateInstalledComponentStateRequest\x12\x64\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02R\rcomponentType\x12$\n\x0binstance_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\ninstanceId\x12z\n\x19installed_component_state\x18\x03 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateB\x03\xe0\x41\x02R\x17installedComponentState\x12,\n\x0finstallation_id\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId\"\'\n%UpdateInstalledComponentStateResponse\"\xc5\x01\n\x1cGetInstalledComponentRequest\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId\x12w\n\x18installed_component_type\x18\x02 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02R\x16installedComponentType\"\x86\x01\n\x1dGetInstalledComponentResponse\x12\x65\n\x13installed_component\x18\x01 \x01(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponentR\x12installedComponent\"N\n\x1eListInstalledComponentsRequest\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId\"\x8a\x01\n\x1fListInstalledComponentsResponse\x12g\n\x14installed_components\x18\x01 \x03(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponentR\x13installedComponents\"[\n+ListInstalledComponentsCurrentStatesRequest\x12,\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0einstallationId\"\xa4\x01\n,ListInstalledComponentsCurrentStatesResponse\x12t\n\x14installed_components\x18\x01 \x03(\x0b\x32\x41.strmprivacy.api.installations.v1.InstalledComponentsCurrentStateR\x13installedComponents2\xd3\x05\n\x1aInstalledComponentsService\x12\xb0\x01\n\x1dUpdateInstalledComponentState\x12\x46.strmprivacy.api.installations.v1.UpdateInstalledComponentStateRequest\x1aG.strmprivacy.api.installations.v1.UpdateInstalledComponentStateResponse\x12\x98\x01\n\x15GetInstalledComponent\x12>.strmprivacy.api.installations.v1.GetInstalledComponentRequest\x1a?.strmprivacy.api.installations.v1.GetInstalledComponentResponse\x12\x9e\x01\n\x17ListInstalledComponents\x12@.strmprivacy.api.installations.v1.ListInstalledComponentsRequest\x1a\x41.strmprivacy.api.installations.v1.ListInstalledComponentsResponse\x12\xc5\x01\n$ListInstalledComponentsCurrentStates\x12M.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesRequest\x1aN.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesResponseBx\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.installed_components_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._serialized_options = b'\340A\002'
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_start=186
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_end=534
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_start=536
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_end=575
  _GETINSTALLEDCOMPONENTREQUEST._serialized_start=578
  _GETINSTALLEDCOMPONENTREQUEST._serialized_end=775
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_start=778
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_end=912
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_start=914
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_end=992
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_start=995
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_end=1133
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_start=1135
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_end=1226
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_start=1229
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_end=1393
  _INSTALLEDCOMPONENTSSERVICE._serialized_start=1396
  _INSTALLEDCOMPONENTSSERVICE._serialized_end=2119
# @@protoc_insertion_point(module_scope)
