# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/batch_exporters/v1/batch_exporters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/batch_exporters/v1/batch_exporters_v1.proto\x12\"strmprivacy.api.batch_exporters.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"b\n\x19ListBatchExportersRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"q\n\x1aListBatchExportersResponse\x12S\n\x0f\x62\x61tch_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\x0e\x62\x61tchExporters\"b\n\x1a\x44\x65leteBatchExporterRequest\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02R\x03ref\"\x1d\n\x1b\x44\x65leteBatchExporterResponse\"o\n\x1a\x43reateBatchExporterRequest\x12Q\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\rbatchExporter\"p\n\x1b\x43reateBatchExporterResponse\x12Q\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\rbatchExporter\"_\n\x17GetBatchExporterRequest\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02R\x03ref\"m\n\x18GetBatchExporterResponse\x12Q\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporterR\rbatchExporter2\xef\x04\n\x15\x42\x61tchExportersService\x12\x93\x01\n\x12ListBatchExporters\x12=.strmprivacy.api.batch_exporters.v1.ListBatchExportersRequest\x1a>.strmprivacy.api.batch_exporters.v1.ListBatchExportersResponse\x12\x8d\x01\n\x10GetBatchExporter\x12;.strmprivacy.api.batch_exporters.v1.GetBatchExporterRequest\x1a<.strmprivacy.api.batch_exporters.v1.GetBatchExporterResponse\x12\x96\x01\n\x13\x44\x65leteBatchExporter\x12>.strmprivacy.api.batch_exporters.v1.DeleteBatchExporterRequest\x1a?.strmprivacy.api.batch_exporters.v1.DeleteBatchExporterResponse\x12\x96\x01\n\x13\x43reateBatchExporter\x12>.strmprivacy.api.batch_exporters.v1.CreateBatchExporterRequest\x1a?.strmprivacy.api.batch_exporters.v1.CreateBatchExporterResponseB~\n%io.strmprivacy.api.batch_exporters.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/batch_exporters/v1;batch_exportersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.batch_exporters.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/batch_exporters/v1;batch_exporters'
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEBATCHEXPORTERREQUEST.fields_by_name['ref']._options = None
  _DELETEBATCHEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERREQUEST.fields_by_name['ref']._options = None
  _GETBATCHEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTBATCHEXPORTERSREQUEST._serialized_start=179
  _LISTBATCHEXPORTERSREQUEST._serialized_end=277
  _LISTBATCHEXPORTERSRESPONSE._serialized_start=279
  _LISTBATCHEXPORTERSRESPONSE._serialized_end=392
  _DELETEBATCHEXPORTERREQUEST._serialized_start=394
  _DELETEBATCHEXPORTERREQUEST._serialized_end=492
  _DELETEBATCHEXPORTERRESPONSE._serialized_start=494
  _DELETEBATCHEXPORTERRESPONSE._serialized_end=523
  _CREATEBATCHEXPORTERREQUEST._serialized_start=525
  _CREATEBATCHEXPORTERREQUEST._serialized_end=636
  _CREATEBATCHEXPORTERRESPONSE._serialized_start=638
  _CREATEBATCHEXPORTERRESPONSE._serialized_end=750
  _GETBATCHEXPORTERREQUEST._serialized_start=752
  _GETBATCHEXPORTERREQUEST._serialized_end=847
  _GETBATCHEXPORTERRESPONSE._serialized_start=849
  _GETBATCHEXPORTERRESPONSE._serialized_end=958
  _BATCHEXPORTERSSERVICE._serialized_start=961
  _BATCHEXPORTERSSERVICE._serialized_end=1584
# @@protoc_insertion_point(module_scope)
