# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/organizations/v1/organizations_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/organizations/v1/organizations_v1.proto\x12 strmprivacy.api.organizations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\x93\x01\n\x12InviteUsersRequest\x12T\n\x0cuser_invites\x18\x01 \x03(\x0b\x32,.strmprivacy.api.organizations.v1.UserInviteB\x03\xe0\x41\x02R\x0buserInvites\x12\'\n\x0forganization_id\x18\x02 \x01(\tR\x0eorganizationId\"\'\n\nUserInvite\x12\x19\n\x05\x65mail\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05\x65mail\"\x8a\x02\n\x13InviteUsersResponse\x12!\n\x0cinvite_count\x18\x01 \x01(\x03R\x0binviteCount\x12]\n\x06issues\x18\x02 \x03(\x0b\x32\x45.strmprivacy.api.organizations.v1.InviteUsersResponse.UserInviteIssueR\x06issues\x1aq\n\x0fUserInviteIssue\x12\x44\n\x06invite\x18\x01 \x01(\x0b\x32,.strmprivacy.api.organizations.v1.UserInviteR\x06invite\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"v\n\x16UpdateUserRolesRequest\x12\x16\n\x06\x65mails\x18\x01 \x03(\tR\x06\x65mails\x12\x44\n\nuser_roles\x18\x02 \x03(\x0e\x32%.strmprivacy.api.entities.v1.UserRoleR\tuserRoles\"\x19\n\x17UpdateUserRolesResponse\" \n\x1eListOrganizationMembersRequest\"w\n\x1fListOrganizationMembersResponse\x12T\n\x14organization_members\x18\x01 \x03(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x13organizationMembers\"&\n\x0eGetUserRequest\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\"H\n\x0fGetUserResponse\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x04user2\xac\x04\n\x14OrganizationsService\x12z\n\x0bInviteUsers\x12\x34.strmprivacy.api.organizations.v1.InviteUsersRequest\x1a\x35.strmprivacy.api.organizations.v1.InviteUsersResponse\x12\x86\x01\n\x0fUpdateUserRoles\x12\x38.strmprivacy.api.organizations.v1.UpdateUserRolesRequest\x1a\x39.strmprivacy.api.organizations.v1.UpdateUserRolesResponse\x12n\n\x07GetUser\x12\x30.strmprivacy.api.organizations.v1.GetUserRequest\x1a\x31.strmprivacy.api.organizations.v1.GetUserResponse\x12\x9e\x01\n\x17ListOrganizationMembers\x12@.strmprivacy.api.organizations.v1.ListOrganizationMembersRequest\x1a\x41.strmprivacy.api.organizations.v1.ListOrganizationMembersResponseBx\n#io.strmprivacy.api.organizations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/organizations/v1;organizationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.organizations.v1.organizations_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.organizations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/organizations/v1;organizations'
  _INVITEUSERSREQUEST.fields_by_name['user_invites']._options = None
  _INVITEUSERSREQUEST.fields_by_name['user_invites']._serialized_options = b'\340A\002'
  _USERINVITE.fields_by_name['email']._options = None
  _USERINVITE.fields_by_name['email']._serialized_options = b'\340A\002'
  _INVITEUSERSREQUEST._serialized_start=174
  _INVITEUSERSREQUEST._serialized_end=321
  _USERINVITE._serialized_start=323
  _USERINVITE._serialized_end=362
  _INVITEUSERSRESPONSE._serialized_start=365
  _INVITEUSERSRESPONSE._serialized_end=631
  _INVITEUSERSRESPONSE_USERINVITEISSUE._serialized_start=518
  _INVITEUSERSRESPONSE_USERINVITEISSUE._serialized_end=631
  _UPDATEUSERROLESREQUEST._serialized_start=633
  _UPDATEUSERROLESREQUEST._serialized_end=751
  _UPDATEUSERROLESRESPONSE._serialized_start=753
  _UPDATEUSERROLESRESPONSE._serialized_end=778
  _LISTORGANIZATIONMEMBERSREQUEST._serialized_start=780
  _LISTORGANIZATIONMEMBERSREQUEST._serialized_end=812
  _LISTORGANIZATIONMEMBERSRESPONSE._serialized_start=814
  _LISTORGANIZATIONMEMBERSRESPONSE._serialized_end=933
  _GETUSERREQUEST._serialized_start=935
  _GETUSERREQUEST._serialized_end=973
  _GETUSERRESPONSE._serialized_start=975
  _GETUSERRESPONSE._serialized_end=1047
  _ORGANIZATIONSSERVICE._serialized_start=1050
  _ORGANIZATIONSSERVICE._serialized_end=1606
# @@protoc_insertion_point(module_scope)
