# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/credentials/v1/credentials_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/credentials/v1/credentials_v1.proto\x12\x1estrmprivacy.api.credentials.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"d\n\x16ListCredentialsRequest\x12J\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x03\xe0\x41\x02R\tstreamRef\"e\n\x17ListCredentialsResponse\x12J\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsR\x0b\x63redentials\"6\n\x17\x44\x65leteCredentialRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\"\x1a\n\x18\x44\x65leteCredentialResponse\"3\n\x14GetCredentialRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\"a\n\x15GetCredentialResponse\x12H\n\ncredential\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsR\ncredential\"`\n\x17\x43reateCredentialRequest\x12\x45\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefR\tstreamRef\"f\n\x18\x43reateCredentialResponse\x12J\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsR\x0b\x63redentials2\xa7\x04\n\x12\x43redentialsService\x12\x82\x01\n\x0fListCredentials\x12\x36.strmprivacy.api.credentials.v1.ListCredentialsRequest\x1a\x37.strmprivacy.api.credentials.v1.ListCredentialsResponse\x12|\n\rGetCredential\x12\x34.strmprivacy.api.credentials.v1.GetCredentialRequest\x1a\x35.strmprivacy.api.credentials.v1.GetCredentialResponse\x12\x85\x01\n\x10\x43reateCredential\x12\x37.strmprivacy.api.credentials.v1.CreateCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.CreateCredentialResponse\x12\x85\x01\n\x10\x44\x65leteCredential\x12\x37.strmprivacy.api.credentials.v1.DeleteCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.DeleteCredentialResponseBr\n!io.strmprivacy.api.credentials.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentialsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.credentials.v1.credentials_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.credentials.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentials'
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._options = None
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._serialized_options = b'\340A\002'
  _LISTCREDENTIALSREQUEST._serialized_start=167
  _LISTCREDENTIALSREQUEST._serialized_end=267
  _LISTCREDENTIALSRESPONSE._serialized_start=269
  _LISTCREDENTIALSRESPONSE._serialized_end=370
  _DELETECREDENTIALREQUEST._serialized_start=372
  _DELETECREDENTIALREQUEST._serialized_end=426
  _DELETECREDENTIALRESPONSE._serialized_start=428
  _DELETECREDENTIALRESPONSE._serialized_end=454
  _GETCREDENTIALREQUEST._serialized_start=456
  _GETCREDENTIALREQUEST._serialized_end=507
  _GETCREDENTIALRESPONSE._serialized_start=509
  _GETCREDENTIALRESPONSE._serialized_end=606
  _CREATECREDENTIALREQUEST._serialized_start=608
  _CREATECREDENTIALREQUEST._serialized_end=704
  _CREATECREDENTIALRESPONSE._serialized_start=706
  _CREATECREDENTIALRESPONSE._serialized_end=808
  _CREDENTIALSSERVICE._serialized_start=811
  _CREDENTIALSSERVICE._serialized_end=1362
# @@protoc_insertion_point(module_scope)
