# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMstrmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto\x12+strmprivacy.api.customer_entity_versions.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\"\x84\x01\n\x1cGetBatchExporterImageRequest\x12\x64\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\"\x97\x01\n\x1dGetBatchExporterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x39\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x05\x18\x01\xe0\x41\x02R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag\"\x1e\n\x1cGetKafkaExporterImageRequest\":\n\x1dGetKafkaExporterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\"\x80\x01\n\x18GetDecrypterImageRequest\x12\x64\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\"\x93\x01\n\x19GetDecrypterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x39\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x05\x18\x01\xe0\x41\x02R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag\"\x85\x01\n\x1dGetBatchJobRunnerImageRequest\x12\x64\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\"\x98\x01\n\x1eGetBatchJobRunnerImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x39\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x05\x18\x01\xe0\x41\x02R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag2\xda\x05\n\x1d\x43ustomerEntityVersionsService\x12\xae\x01\n\x15GetBatchExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageResponse\x12\xae\x01\n\x15GetKafkaExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageResponse\x12\xa2\x01\n\x11GetDecrypterImage\x12\x45.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageRequest\x1a\x46.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageResponse\x12\xb1\x01\n\x16GetBatchJobRunnerImage\x12J.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageRequest\x1aK.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageResponseB\x99\x01\n.io.strmprivacy.api.customer_entity_versions.v1P\x01Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.strmprivacy.api.customer_entity_versions.v1P\001Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versions'
  _GETBATCHEXPORTERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETBATCHEXPORTERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETDECRYPTERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETBATCHJOBRUNNERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_start=212
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_end=344
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_start=347
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_end=498
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_start=500
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_end=530
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_start=532
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_end=590
  _GETDECRYPTERIMAGEREQUEST._serialized_start=593
  _GETDECRYPTERIMAGEREQUEST._serialized_end=721
  _GETDECRYPTERIMAGERESPONSE._serialized_start=724
  _GETDECRYPTERIMAGERESPONSE._serialized_end=871
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_start=874
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_end=1007
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_start=1010
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_end=1162
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_start=1165
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_end=1895
# @@protoc_insertion_point(module_scope)
