# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.consent_levels.v1 import consent_levels_v1_pb2 as strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2


class ConsentLevelMappingsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListConsentLevelMappings = channel.unary_unary(
                '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/ListConsentLevelMappings',
                request_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsResponse.FromString,
                )
        self.GetConsentLevelMapping = channel.unary_unary(
                '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/GetConsentLevelMapping',
                request_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingResponse.FromString,
                )
        self.DeleteConsentLevelMapping = channel.unary_unary(
                '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/DeleteConsentLevelMapping',
                request_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingResponse.FromString,
                )
        self.CreateConsentLevelMapping = channel.unary_unary(
                '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/CreateConsentLevelMapping',
                request_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingResponse.FromString,
                )


class ConsentLevelMappingsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListConsentLevelMappings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConsentLevelMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConsentLevelMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConsentLevelMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConsentLevelMappingsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListConsentLevelMappings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConsentLevelMappings,
                    request_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsResponse.SerializeToString,
            ),
            'GetConsentLevelMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConsentLevelMapping,
                    request_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingResponse.SerializeToString,
            ),
            'DeleteConsentLevelMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConsentLevelMapping,
                    request_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingResponse.SerializeToString,
            ),
            'CreateConsentLevelMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConsentLevelMapping,
                    request_deserializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConsentLevelMappingsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListConsentLevelMappings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/ListConsentLevelMappings',
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsRequest.SerializeToString,
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.ListConsentLevelMappingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConsentLevelMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/GetConsentLevelMapping',
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingRequest.SerializeToString,
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.GetConsentLevelMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConsentLevelMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/DeleteConsentLevelMapping',
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingRequest.SerializeToString,
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.DeleteConsentLevelMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConsentLevelMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.consent_levels.v1.ConsentLevelMappingsService/CreateConsentLevelMapping',
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingRequest.SerializeToString,
            strmprivacy_dot_api_dot_consent__levels_dot_v1_dot_consent__levels__v1__pb2.CreateConsentLevelMappingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
